***IMPORTING DATATSET***
use "C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\employmenteducation.dta"

***INSPECTING DATA***
*Inspecting means of all variables.
summarize

*Outliers
dotplot tstatistic
extremes tstatistic

dotplot se_pcc
extremes se_pcc

dotplot pcc
extremes pcc

*Graphs and summary statistics.
sum pcc, detail
sum se_pcc, detail
sum tstatistic, detail

hist pcc
hist se_pcc
hist tstatistic

*Dropping outlier observations.
gen odd =0
replace odd=1 in 282
replace odd=1 in 285
replace odd=1 in 288
replace odd=1 in 424
replace odd=1 in 117
drop if odd==1
drop odd

*Dropping observations if pcc and se_pcc missing.
drop if missing(se_pcc)
drop if missing(pcc)

***WINSORIZING DATA***
*Winsorizing data (Winsorized variables do not have any suffix, unwinsorized variables have the suffix _unwinsor.)
winsor pcc, generate(pcc_winsor) p(0.01)
winsor se_pcc, generate(se_pcc_winsor) p(0.01)
winsor sample_size, generate(sample_size_winsor) p(0.01)
winsor tstatistic, generate(tstatistic_winsor) p (0.01)
generate pcc_unwinsor = pcc
generate se_pcc_unwinsor = se_pcc
generate sample_size_unwinsor = sample_size
generate tstatistic_unwinsor = tstatistic
replace pcc = pcc_winsor
replace se_pcc = se_pcc_winsor
replace sample_size = sample_size_winsor
replace tstatistic = tstatistic_winsor


***GRAPHS***

*Boxplot of PCCs across individual studies.
graph hbox pcc, over(title) xsize(13) ysize(18) scale(0.35) graphregion(color(white))

*Histogram for all PCCs (The graph does not show winsorized values at the tails for a better readibility, however, we include these values in all subsequent quantitative tests.)
quietly sum pcc, detail
local m=r(mean)
local median=r(p50)
histogram pcc if pcc > -0.23 & pcc < 0.13, bin(50) frequency xline(`m', lp(solid) lcolor(gs0)) xline(`median', lp(dash) lcolor(gs0)) xtitle("Estimate of the Student Employment Coefficient") graphregion(color(white))

*Boxplot of PCCs across countries.
graph hbox pcc, over(country) graphregion(color(white))

*Time trend of PCCs.
graph twoway (scatter pcc publication_date, msize(*1) msymbol(Oh)) (lfit pcc publication_date, lcolor(black)),  xtitle("Publication year") ytitle("Partial correlation coefficient") graphregion(color(white)) legend(off)


***SUMMARY STATISTICS***
*For all PCCs.
sum pcc, detail
count if pcc<0 & tstatistic<-1.96
count if pcc<0 & tstatistic>-1.96
count if pcc>0 & tstatistic>1.96
count if pcc>0 & tstatistic<1.96

**Number of estimates in a given study
bysort idstudy: egen no_estimates = count(pcc)
gen inv_no_estimates = 1/no_estimates

**Simple arithmetic mean.
mean pcc

**Weighted mean.
mean pcc[aweight=inv_no_estimates]

*Summary statistics for different subsets of data.
mean pcc if endogeneity==1
mean pcc if endogeneity==0

mean pcc if longitudinal_data==1
mean pcc if longitudinal_data==0

mean pcc if male==1
mean pcc if female==1

mean pcc if educational_level==1
mean pcc if educational_level==0

mean pcc if education_choice==1
mean pcc if education_attainment==1
mean pcc if testscores==1

mean pcc if employment_dummy==1
mean pcc if employment_continuous==1
mean pcc if employment_categorical==1
mean pcc if low_intensity==1
mean pcc if medium_intensity==1
mean pcc if high_intensity==1

mean pcc if panel_method==1
mean pcc if elementary_approach==1
mean pcc if matching_approach==1
mean pcc if joint_modelling==1
mean pcc if dynamic_discrete==1

mean pcc if europe==1
mean pcc if usa==1
mean pcc if othercountries==1

mean pcc if published==0
mean pcc if published==1

mean pcc if publication_date>1978 & publication_date<1991
mean pcc if publication_date>1991 & publication_date<2001
mean pcc if publication_date>2001 & publication_date<2011
mean pcc if publication_date>2011

mean pcc [aweight=inv_no_estimates] if endogeneity==1
mean pcc [aweight=inv_no_estimates] if endogeneity==0

mean pcc [aweight=inv_no_estimates] if longitudinal_data==1
mean pcc [aweight=inv_no_estimates] if longitudinal_data==0

mean pcc [aweight=inv_no_estimates] if male==1
mean pcc [aweight=inv_no_estimates] if female==1

mean pcc [aweight=inv_no_estimates] if educational_level==1
mean pcc [aweight=inv_no_estimates] if educational_level==0

mean pcc [aweight=inv_no_estimates] if education_choice==1
mean pcc [aweight=inv_no_estimates] if education_attainment==1
mean pcc [aweight=inv_no_estimates] if testscores==1

mean pcc [aweight=inv_no_estimates] if employment_dummy==1
mean pcc [aweight=inv_no_estimates] if employment_continuous==1
mean pcc [aweight=inv_no_estimates] if employment_categorical==1

mean pcc [aweight=inv_no_estimates] if low_intensity==1
mean pcc [aweight=inv_no_estimates] if medium_intensity==1
mean pcc [aweight=inv_no_estimates] if high_intensity==1

mean pcc [aweight=inv_no_estimates] if panel_method==1
mean pcc [aweight=inv_no_estimates] if elementary_approach==1
mean pcc [aweight=inv_no_estimates] if matching_approach==1
mean pcc [aweight=inv_no_estimates] if joint_modelling==1
mean pcc [aweight=inv_no_estimates] if dynamic_discrete==1

mean pcc [aweight=inv_no_estimates] if europe==1
mean pcc [aweight=inv_no_estimates] if usa==1
mean pcc [aweight=inv_no_estimates] if othercountries==1

mean pcc [aweight=inv_no_estimates] if published==0
mean pcc [aweight=inv_no_estimates] if published==1

mean pcc [aweight=inv_no_estimates] if publication_date>1978 & publication_date<1991
mean pcc [aweight=inv_no_estimates] if publication_date>1991 & publication_date<2001
mean pcc [aweight=inv_no_estimates] if publication_date>2001 & publication_date<2011
mean pcc [aweight=inv_no_estimates] if publication_date>2011


*Summary statistics for explanatory variables.
mean pcc
mean se_pcc
mean sample_size_ln
mean data_year_ln
mean longitudinal_data
mean elementary_approach
mean matching_approach
mean panel_method
mean joint_modelling
mean dynamic_discrete
mean endogeneity
mean europe
mean usa
mean othercountries
mean educational_level
mean number_variables_ln
mean education_choice
mean education_attainment
mean testscores
mean employment_continuous
mean employment_dummy
mean employment_categorical
mean publication_date_ln
mean number_citations_ln
mean published_dummy
mean JCR_impact_factor
mean ability
mean motivation
mean parental_education
mean age
mean gender
mean ethnicity
mean male
mean female
mean class_attendance
mean studytime
mean child
mean marital_status

***PUBLICATION BIAS***

*Funnel plot
gen precision = 1/se_pcc
quietly sum pcc_unwinsor, detail
local m = r(mean)
local median = r(p50)
scatter precision pcc_unwinsor, msize(*.6) msymbol(Oh) xline(`m', lp(solid) lcolor(gs0)) xline(`median', lp(dash) lcolor(gs0)) xtitle("Partial correlation coefficient") ytitle("Precision of the partial correlation coefficient (1/SE)") graphregion(color(white))

*Funnel assymetry test
ssc install ivreg2
xtset idstudy

**OLS
eststo: ivreg2 pcc se_pcc, cluster (idstudy)
boottest se_pcc
boottest _cons 
** "Study"
eststo: ivreg2 pcc se_pcc [pweight=inv_no_estimates], cluster (idstudy)
boottest se_pcc
boottest _cons 
**IV
gen invsqrtsamplesize = 1/sqrt(sample_size)
eststo: ivreg2 pcc (se_pcc = invsqrtsamplesize), cluster (idstudy)
boottest se_pcc
boottest _cons
**Between-estimation
eststo: xtreg pcc se_pcc, be
estout, cells(b(star fmt(3)) se(par fmt(2)))
eststo clear 

**Accounting for heteroscedasticity.
* Calculating new values for t-statistic due to winsorization of pcc and se_pcc.
gen tvalue=pcc/se_pcc
**WLS - "Precision"
eststo: ivreg2 pcc se_pcc [pweight=precision], cluster (idstudy)
boottest se_pcc 
boottest _cons 
**WLS - "Study"
eststo: ivreg2 tvalue precision [pweight=inv_no_estimates], cluster (idstudy)
boottest precision
boottest _cons
**IV
eststo: ivreg2 tvalue (precision = invsqrtsamplesize), cluster (idstudy)
boottest precision
boottest _cons
**Between-estimation
eststo: xtreg tvalue precision, be
estout, cells(b(star fmt(3)) se(par fmt(2)))
eststo clear 


**CALIPER TEST
histogram tstatistic_unwinsor, bin(60) fcolor(gs14) lstyle(thin) frequency normal xtitle("t-statistics of the PCC") xline(-1.96 0 1.96 , lcolor(navy)) graphregion(color(white))

generate significantlevel = 0
replace significantlevel = 1 if tstatistic > 1.96 | tstatistic < - 1.96

**threshold for t = 1.96
*10%
reg significantlevel if tstatistic > 1.76 & tstatistic < 2.16
*5%
reg significantlevel if tstatistic > 1.86 & tstatistic < 2.06

**threshold for t = -1.96
*10%
reg significantlevel if tstatistic < -1.76 & tstatistic > -2.16
*5%
reg significantlevel if tstatistic < -1.86 & tstatistic > -2.06
 
**threshold for t = 0
generate significantsign = 0
replace significantsign = 1 if tstatistic > 0
*10%
reg significantsign if tstatistic > -0.1 & tstatistic < 0.1
*5%
reg significantsign if tstatistic > -0.05 & tstatistic < 0.05
 

*NONLINEAR METHODS
**WAAP (Weighted Average of Adequately Powered, Ioannidis et al., 2017) - Test could not be conducted on winsorized data, thus unwinsorized data are used.
quietly sum pcc_unwinsor [aweight=1/(se_pcc_unwinsor*se_pcc_unwinsor)], detail
gen waapbound = abs(r(mean))/2.8
mean pcc if se_pcc_unwinsor < waapbound
mean pcc if se_pcc_unwinsor < waapbound & published==1

**Selection model by Andrews & Kasy, 2019
*https://maxkasy.github.io/home/metastudy/ (web application)

**Stem-based method by Furukawa, 2019
*R code used://github.com/Chishio318/stem-based_method (R code)
/*
source("stem_method.R")
dataeducation=read.csv("Furukawa_wholesample.csv")
stem_results = stem(dataeducation$pcc, dataeducation$se_pcc, param)
View(stem_results$estimates)
stem_funnel (dataeducation$pcc, dataeducation$se_pcc, stem_results$estimates)
*/

**Endogenous Kink Technique by Bonn and Rachinger, 2019 (code from https://sites.google.com/site/heikorachinger/codes), results must be read with a reversed sign

quietly {

rename pcc bs
rename se_pcc sebs

log using quiet_noise.log, text replace
 
gen ones=1
   
sum
local M=r(N)
sum sebs
local sebs_min=r(min)
local sebs_max=r(max)
  
gen sebs2=sebs^2
gen wis=ones/sebs2
gen bs_sebs=bs/sebs
gen ones_sebs=ones/sebs

gen bswis=bs*wis
sum wis
local wis_sum=r(sum)


* FAT-PET
regress bs_sebs ones_sebs ones,noc
local pet=_b[ones_sebs]
local t1_linreg = (_b[ones_sebs]/_se[ones_sebs])
local b_lin=_b[ones_sebs]
local Q1_lin = e(rss)
di `t1_linreg'
local abs_t1_linreg = abs(`t1_linreg')
di `abs_t1_linreg'


* PEESE
regress bs_sebs ones_sebs sebs,noc
local peese=_b[ones_sebs]
local b_sq=_b[ones_sebs]
local Q1_sq = e(rss)
di `Q1_sq'
 

* FAT-PET-PEESE

if `abs_t1_linreg' > invt(`M-2', 0.975) {
    local combreg=`b_sq'
	local Q1=`Q1_sq'
	}
else {
    local combreg=`b_lin'
	local Q1=`Q1_lin'
}

* estimation of random effects variance component
local sigh2hat=max(0,`M'*((`Q1'/(`M'-e(df_m)-1))-1)/`wis_sum') 
local sighhat=sqrt(`sigh2hat') 


* Cutoff value for EK
if `combreg'>1.96*`sighhat' {
    local a1=(`combreg'-1.96*`sighhat')*(`combreg'+1.96*`sighhat')/(2*1.96*`combreg')
}
else {
	local a1=0
	}
    
	
	rename bs bs_original
	rename bs_sebs bs
	rename ones_sebs constant
	rename ones pub_bias
	
	
    noisily: display "EK regression: "

if `a1'>`sebs_min' & `a1'<`sebs_max' {
    gen sebs_a1=sebs-`a1' if sebs>`a1'
	replace sebs_a1=0 if sebs<=`a1'
	gen pubbias=sebs_a1/sebs
	noisily regress bs constant pubbias, noc
	local b0_ek=_b[constant]
	local b1_ek=_b[pubbias]
	local sd0_ek=_se[constant]
	local sd1_ek=_se[pubbias]
}
else if `a1'<`sebs_min' {
    noisily regress bs constant pub_bias, noc
	local b0_ek=_b[constant]
	local b1_ek=_b[pub_bias]
	local sd0_ek=_se[constant]
	local sd1_ek=_se[pub_bias]
}
else if `a1'>`sebs_max' {
    noisily regress bs constant, noc
	local b0_ek=_b[constant]
	local sd0_ek=_se[constant]	
}
noisily: display "EK's mean effect estimate (alpha1) and standard error:"
noisily: di `b0_ek' 
noisily: di `sd0_ek' 
noisily: display "EK's publication bias estimate (delta) and standard error:"
noisily: di `b1_ek' 
noisily: di `sd1_ek' 

log close
}

***BMA and FMA***

drop marital_status child class_attendance studytime twoyear_college parttime_student undergraduate_students subsidy employment_oncampus

*Preparing datasets.
***Unweighted
clear

use "use "C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\employmenteducation.dta""

replace JCR_impact_factor=0 if JCR_impact_factor==.

keep pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor

order pcc se_pcc employment_continuous ability education_choice citations longitudinal_data europe elementary_approach educational_level matching_approach usa age education_attainment JCR_impact_factor ethnicity joint_modelling parental_education published_dummy female data_year_ln male publication_date_ln number_variables_ln panel_methods emplyoment_dummy motivation

export excel using"C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\bma_dataset.xls", sheet("unweighted") firstrow(variables)


***Dataset weighted by the reported precision of the estimates 
local weightedvarsse "pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor"

foreach var in  `weightedvarsse' {
				replace `var' = `var'/sqrt(se_pcc)
}
drop se_pcc

export excel using "C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\bma_dataset.xls", sheet("weighted_se") firstrow(variables)

***Dataset weighted by the inverse of the number of estimates reported per study
clear
use "use "C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\employmenteducation_winsorized.dta"

keep pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor inv_no_estimates

local weightedvarsinvperstudy "pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor" 
foreach var of varlist `weightedvarsinvperstudy' {
				replace `var' = `var' * sqrt(inv_no_estimates)
}
drop inv_no_estimates

export excel using "C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\bma_dataset.xls", sheet("weighted_inv_no_estimates") firstrow(variables)

***BMA in R***
/*
library(readxl)
dataeducation=read_excel("/Users/Kateřina/OneDrive/Plocha/_DIPLOMKA/STATA/emplyomenteducation_dofiles, data/bma_dataset.xls", sheet = 1)
library(BMS)

education = bms(dataeducation, burn=1000000,iter=2000000, g="UIP", mprior="dilut", nmodel=5000, mcmc="bd", user.int=FALSE)

coef(education, order.by.pip = F, exact=T, include.constant=T)
image(education, yprop2pip=FALSE, order.by.pip=TRUE, do.par=TRUE, do.grid=TRUE, do.axis=TRUE, cex.axis = 0.7)
summary(education)
plot(education)
print(education$topmod[1])
density(education, reg="private")

library(corrplot)
dataeducation=read_excel("/Users/Kateřina/OneDrive/Plocha/_DIPLOMKA/STATA/emplyomenteducation_dofiles, data/bma_dataset.xls", sheet = 1)
col<- colorRampPalette(c("red", "white", "blue"))
M <- cor(dataeducation)
corrplot.mixed(M, lower = "number", upper = "circle", lower.col=col(200), upper.col=col(200), tl.pos = c("lt"), diag = c("u"), tl.col="black", tl.srt=45, tl.cex=0.85, number.cex = 0.5, cl.cex=0.8, cl.ratio=0.1)

***FMA in R***

library(foreign)
library(xtable)
library(LowRankQP)
dataeducation=read_excel("/Users/Kateřina/OneDrive/Plocha/_DIPLOMKA/STATA/emplyomenteducation_dofiles, data/bma_dataset.xls", sheet = 1)

dataeducation <-na.omit(dataeducation)
x.data <- dataeducation[,-1]
const_<-c(1)
x.data <-cbind(const_,x.data)
x <- sapply(1:ncol(x.data),function(i){x.data[,i]/max(x.data[,i])})   
scale.vector <- as.matrix(sapply(1:ncol(x.data),function(i){max(x.data[,i])}))        
Y <- as.matrix(dataeducation[,1])
output.colnames <- colnames(x.data)
full.fit <- lm(Y~x-1)
beta.full <- as.matrix(coef(full.fit))
M <- k <- ncol(x)
n <- nrow(x)
beta <- matrix(0,k,M)
e <- matrix(0,n,M)
K_vector <- matrix(c(1:M))
var.matrix <- matrix(0,k,M)
bias.sq <- matrix(0,k,M)             
# MMA Estimator using orthogonalization 
for(i in 1:M)
{
  X <- as.matrix(x[,1:i])
  ortho <- eigen(t(X)%*%X)
  Q <- ortho$vectors ; lambda <- ortho$values 
  x.tilda <- X%*%Q%*%(diag(lambda^-0.5,i,i))
  beta.star <- t(x.tilda)%*%Y
  beta.hat <- Q%*%diag(lambda^-0.5,i,i)%*%beta.star
  beta[1:i,i] <- beta.hat
  e[,i] <- Y-x.tilda%*%as.matrix(beta.star)
  bias.sq[,i] <- (beta[,i]-beta.full)^2
  var.matrix.star <- diag(as.numeric(((t(e[,i])%*%e[,i])/(n-i))),i,i)
  var.matrix.hat <- var.matrix.star%*%(Q%*%diag(lambda^-1,i,i)%*%t(Q))
  var.matrix[1:i,i] <- diag(var.matrix.hat)
  var.matrix[,i] <- var.matrix[,i]+ bias.sq[,i]
} # End loop over i
e_k <- e[,M]
sigma_hat <- as.numeric((t(e_k)%*%e_k)/(n-M))
G <- t(e)%*%e
a <- ((sigma_hat)^2)*K_vector
A <- matrix(1,1,M)
b <- matrix(1,1,1)
u <- matrix(1,M,1)
optim <- LowRankQP(Vmat=G,dvec=a,Amat=A,bvec=b,uvec=u,method="LU",verbose=FALSE)
weights <- as.matrix(optim$alpha)
beta.scaled <- beta%*%weights
final.beta <- beta.scaled/scale.vector
std.scaled <- sqrt(var.matrix)%*%weights
final.std <- std.scaled/scale.vector
results.reduced <- as.matrix(cbind(final.beta,final.std))
rownames(results.reduced) <- output.colnames; colnames(results.reduced) <- c("Coefficient", "Sd. Err")
MMA.fls <- round(results.reduced,4)
MMA.fls <- data.frame(MMA.fls)
t <- as.data.frame(MMA.fls$Coefficient/MMA.fls$Sd..Err)
MMA.fls$pv <-round( (1-apply(as.data.frame(apply(t,1,abs)), 1, pnorm))*2,3)
MMA.fls$names <- rownames(MMA.fls)
names <- c(colnames(dataeducation))
names <- c(names,"const_")
MMA.fls <- MMA.fls[match(names, MMA.fls$names),]
MMA.fls$names <- NULL
MMA.fls
*/

*Frequentist check
eststo: ivreg2 pcc se_pcc employment_continuous ability education_choice number_citations_ln longitudinal_data europe[pweight=inv_no_estimates], cluster(idstudy)
estout, cells(b(star fmt(3)) se(par fmt(2)))
eststo clear

***BEST PRACTICE ESTIMATES***

*Confidence intervals for the best practice estimates.
use "C:\Users\Kateřina\OneDrive\Plocha\_DIPLOMKA\STATA\emplyomenteducation_dofiles, data\employmenteducation.dta"

keep pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor inv_no_estimates idstudy

local weightedvarsinvperstudy "pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor" 
foreach var of varlist `weightedvarsinvperstudy' {
				replace `var' = `var' * sqrt(inv_no_estimates)
}
drop inv_no_estimates

ssc install ivreg2
xtset idstudy

ivreg2 pcc se_pcc data_year_ln longitudinal_data elementary_approach matching_approach panel_method joint_modelling europe usa educational_level number_variables_ln education_choice education_attainment employment_continuous employment_dummy publication_date_ln number_citations_ln published_dummy ability motivation parental_education age ethnicity male female JCR_impact_factor, cluster(idstudy)

*All
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 + elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*0.2463768 + usa*0.6376812 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*0.1713495 + education_attainment*0.175542 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664
*Europe
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 +elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*1 + usa*0 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*0.1713495 + education_attainment*0.175542 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664
*USA
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 +elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*0 + usa*1 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*0.1713495 + education_attainment*0.175542 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664
*Other countries
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 +elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*0 + usa*0 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*0.1713495 + education_attainment*0.175542 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664
*Education:Choice
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 +elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*0.2463768 + usa*0.6376812 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*1 + education_attainment*0 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664
*Education:Attainment
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 +elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*0.2463768 + usa*0.6376812 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*0 + education_attainment*1 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664
*Test scores
lincom  se_pcc*0.0048821 + data_year_ln*3.89182 + longitudinal_data*1 +elementary_approach*0 + matching_approach*0 + panel_method*1 + joint_modelling*1 + europe*0.2463768 + usa*0.6376812 + educational_level*0.4671126 + number_variables_ln*2.450763 + education_choice*0 + education_attainment*0 + employment_continuous*1 + employment_dummy*0.156173 + publication_date_ln*3.738661 + number_citations_ln*1.548496 + published_dummy*1 + JCR_impact_factor*5.013 + ability*1 + motivation*1 + parental_education*1 + age*1 + ethnicity*1 + male*0.106087 + female*0.0839664

***GENERATING SUBSAMPLES***
*Here, we show how we created the subsamples. After creating the subsamples, we run the relevant parts of the code for the subsample.

*Subsample of studies controlling for endogeneity.
keep if endogeneity==1

*Subsample of studies specifying student employment as a continuous variable.
keep if employment_continuous==1

*Subsample of homogenous untransformed estimates (Consequently, instead of working with variable pcc and se_pcc, we utilize variables estimate and se_estimate.)
keep if homogenous_subsample==1

*Subsample of studies specifying student employment as categorical variable.
keep if employment_categorical==1